# Business Capabilities in the Reference Catalog
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#benefits)
  * [Permissions](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#permissions)
  * [Import Business Capabilities from the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#import-business-capabilities-from-the-reference-catalog)
  * [Imported Fields](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#imported-fields)
  * [Link Existing Business Capabilities to Catalog Items](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#link-existing-business-capabilities-to-catalog-items)
  * [Bulk Linking Business Capability Fact Sheets](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#bulk-linking-business-capability-fact-sheets)
  * [Linking a Business Capability Fact Sheet from the Fact Sheet Page](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog#linking-a-business-capability-fact-sheet-from-the-fact-sheet-page)


View all
Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.
